@@ -37,7 +37,7 @@ struct VteBgCacheItem {
 	GdkPixbuf *source_pixbuf;
 	char *source_file;
 
-	GdkColor tint_color;
+	PangoColor tint_color;
 	double saturation;
 
 	GdkPixmap *pixmap;
@@ -243,7 +243,7 @@ vte_bg_class_init(VteBgClass *klass)
 						  0,
 						  NULL,
 						  NULL,
-						  _vte_marshal_VOID__VOID,
+                                                  g_cclosure_marshal_VOID__VOID,
 						  G_TYPE_NONE, 0);
 	g_type_class_add_private(klass, sizeof (struct VteBgPrivate));
 }
@@ -293,7 +293,7 @@ vte_bg_get_for_screen(GdkScreen *screen)
 /* Generate lookup tables for desaturating an image toward a given color.  The
  * saturation value is a floating point number between 0 and 1. */
 static void
-_vte_bg_generate_desat_tables(const GdkColor *color, double saturation,
+_vte_bg_generate_desat_tables(const PangoColor *color, double saturation,
 			      guchar red[256],
 			      guchar green[256],
 			      guchar blue[256])
@@ -330,7 +330,7 @@ _vte_bg_generate_desat_tables(const GdkColor *color, double saturation,
 }
 
 static gboolean
-vte_bg_colors_equal(const GdkColor *a, const GdkColor *b)
+vte_bg_colors_equal(const PangoColor *a, const PangoColor *b)
 {
 	return  (a->red >> 8) == (b->red >> 8) &&
 		(a->green >> 8) == (b->green >> 8) &&
@@ -343,16 +343,16 @@ vte_bg_cache_item_free(struct VteBgCacheItem *item)
 	/* Clean up whatever is left in the structure. */
 	if (item->source_pixbuf != NULL) {
 		g_object_remove_weak_pointer(G_OBJECT(item->source_pixbuf),
-				(gpointer*)&item->source_pixbuf);
+				(gpointer*)(void*)&item->source_pixbuf);
 	}
 	g_free(item->source_file);
 	if (item->pixmap != NULL) {
 		g_object_remove_weak_pointer(G_OBJECT(item->pixmap),
-				(gpointer*)&item->pixmap);
+				(gpointer*)(void*)&item->pixmap);
 	}
 	if (item->pixbuf != NULL) {
 		g_object_remove_weak_pointer(G_OBJECT(item->pixbuf),
-				(gpointer*)&item->pixbuf);
+				(gpointer*)(void*)&item->pixbuf);
 	}
 
 	g_slice_free(struct VteBgCacheItem, item);
@@ -441,22 +441,22 @@ vte_bg_cache_add(VteBg *bg, struct VteBgCacheItem *item)
 	bg->pvt->cache = g_list_prepend(bg->pvt->cache, item);
 	if (item->source_pixbuf != NULL) {
 		g_object_add_weak_pointer(G_OBJECT(item->source_pixbuf),
-					  (gpointer*)&item->source_pixbuf);
+					  (gpointer*)(void*)&item->source_pixbuf);
 	}
 	if (item->pixbuf != NULL) {
 		g_object_add_weak_pointer(G_OBJECT(item->pixbuf),
-					  (gpointer*)&item->pixbuf);
+					  (gpointer*)(void*)&item->pixbuf);
 	}
 	if (item->pixmap != NULL) {
 		g_object_add_weak_pointer(G_OBJECT(item->pixmap),
-					  (gpointer*)&item->pixmap);
+					  (gpointer*)(void*)&item->pixmap);
 	}
 }
 
 /* Desaturate a pixbuf in the direction of a specified color. */
 static void
 vte_bg_desaturate_pixbuf(GdkPixbuf *pixbuf,
-			 const GdkColor *tint, double saturation)
+			 const PangoColor *tint, double saturation)
 {
 	guchar red[256], green[256], blue[256];
 	long stride, width, height, channels, x, y;
@@ -497,7 +497,7 @@ vte_bg_cache_search(VteBg *bg,
 		    enum VteBgSourceType source_type,
 		    const GdkPixbuf *source_pixbuf,
 		    const char *source_file,
-		    const GdkColor *tint,
+		    const PangoColor *tint,
 		    double saturation,
 		    GdkVisual *visual,
 		    gboolean pixbuf,
@@ -547,7 +547,7 @@ vte_bg_get_pixmap(VteBg *bg,
 		  enum VteBgSourceType source_type,
 		  GdkPixbuf *source_pixbuf,
 		  const char *source_file,
-		  const GdkColor *tint,
+		  const PangoColor *tint,
 		  double saturation,
 		  GdkColormap *colormap)
 {
@@ -555,7 +555,6 @@ vte_bg_get_pixmap(VteBg *bg,
 	gpointer cached;
 	GdkColormap *rcolormap;
 	GdkPixmap *pixmap;
-	GdkBitmap *mask;
 	GdkPixbuf *pixbuf;
 	char *file;
 
@@ -652,7 +651,6 @@ vte_bg_get_pixmap(VteBg *bg,
 	}
 
 	pixmap = NULL;
-	mask = NULL;
 	if (GDK_IS_PIXBUF(pixbuf)) {
 		/* If the image is smaller than 256x256 then tile it into a
 		 * pixbuf that is at least this large.  This is done because
@@ -661,11 +659,8 @@ vte_bg_get_pixmap(VteBg *bg,
 		pixbuf = _vte_bg_resize_pixbuf(pixbuf, 256, 256);
 		gdk_pixbuf_render_pixmap_and_mask_for_colormap(pixbuf,
 							       colormap,
-							       &pixmap, &mask,
+							       &pixmap, NULL,
 							       0);
-		if (mask != NULL) {
-			g_object_unref(mask);
-		}
 		g_object_unref(pixbuf);
 	}
 
