@@ -62,14 +62,9 @@ enum VteBgSourceType {
 GdkPixmap *vte_bg_get_pixmap(VteBg *bg, enum VteBgSourceType source_type,
 			     GdkPixbuf *source_pixbuf,
 			     const char *source_file,
-			     const GdkColor *tint, double saturation,
+			     const PangoColor *tint, double saturation,
 			     GdkColormap *colormap);
 
-GdkPixbuf *vte_bg_get_pixbuf(VteBg *bg, enum VteBgSourceType source_type,
-			     GdkPixbuf *source_pixbuf,
-			     const char *source_file,
-			     const GdkColor *tint, double saturation);
-
 G_END_DECLS
 
 #endif
